/* $Id: resource.h 37549 2011-06-20 08:44:19Z vboxsync $ */
/** @file
 * resource.h - resource header file.
 */

/*
 * Copyright (C) 2010 Oracle Corporation
 *
 * This file is part of VirtualBox Open Source Edition (OSE), as
 * available from http://www.virtualbox.org. This file is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License (GPL) as published by the Free Software
 * Foundation, in version 2 as it comes in the "COPYING" file of the
 * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
 */

#define IDI_VIRTUALBOX              101

#define IDI_FILETYPE_VBOX           201
#define IDI_FILETYPE_VBOX_EXTPACK   202

#define IDI_FILETYPE_VBOX_OVF       301
#define IDI_FILETYPE_VBOX_OVA       302
#define IDI_FILETYPE_VBOX_VDI       303
#define IDI_FILETYPE_VBOX_VMDK      304
#define IDI_FILETYPE_VBOX_VHD       305
#define IDI_FILETYPE_VBOX_HDD       306
